@@ -21,7 +21,7 @@
 
 int new_handler_called = 0;
 
-void new_handler()
+void my_new_handler()
 {
     ++new_handler_called;
     std::set_new_handler(0);
@@ -37,7 +37,7 @@ struct A
 
 int main()
 {
-    std::set_new_handler(new_handler);
+    std::set_new_handler(my_new_handler);
 #ifndef TEST_HAS_NO_EXCEPTIONS
     try
 #endif
